==> Epics.uv8.00.tar.gz: prog/Elemag/epExpot.f <==
c       ***************************************************************
c       *
c       *  epExpot:  compute excitation potential (in eV)
c       *            consisting of n different atoms.
c          
c         ---------------------------------
c          must be called after epGetEffZA
c         ---------------------------------
c       *
c
c /usage/ call epExpot(media)
c      
c           see p.r. b vol3 (1971)3681 sternheimer.  c

       subroutine epExpot(media)
       implicit none
#include "Zmedia.h"

       record /epmedia/media  !  input.  data  given by basic table must
                            !          be ready
                            !  output. media.I. ionization potential in GeV

       integer n

       integer i
       real*8 sumli, expi

       real expot(92)
c
c   From  http://physics.nist.gov/PhysRefData/XrayMassCoef/tab1.html
c    expot(Z) is excitation poential for Z in eV. Sep. 7, 2002
c
       data expot/
     1 19.2,  41.8,  40.0,  63.7,  76.0,   78.0,  82.0,  95.0, 115.0,
     2 137.0, 149.0, 156.0, 166.0, 173.0, 173.0, 180.0, 174.0, 188.0,
     3 190.0, 191.0, 216.0, 233.0, 245.0, 257.0, 272.0, 286.0, 297.0,
     4 311.0, 322.0, 330.0, 334.0, 350.0, 347.0, 348.0, 343.0, 352.0,
     5 363.0, 366.0, 379.0, 393.0, 417.0, 424.0, 428.0, 441.0, 449.0,
     6 470.0, 470.0, 469.0, 488.0, 488.0, 487.0, 485.0, 491.0, 482.0, 
     7 488.0, 491.0, 501.0, 523.0, 535.0, 546.0, 560.0, 574.0, 580.0,
     8 591.0, 614.0, 628.0, 650.0, 658.0, 674.0, 684.0, 694.0, 705.0,
     9 718.0, 727.0, 736.0, 746.0, 757.0, 790.0, 790.0, 800.0, 810.0,
     a 823.0, 823.0, 830.0, 825.0, 794.0, 827.0, 826.0, 841.0, 847.0,
     b 878.0, 890.0/


       sumli=0.



       n = media.noOfElem

       do  i = 1, n
c          if(media.elem(i).Z .eq. 1) then
c             expi=18.7
c          elseif(media.elem(i).Z .lt. 13.0) then
c             expi=13.*media.elem(i).Z
c          else
c             expi=media.elem(i).Z *( 9.76 + 58.8*
c     *            media.elem(i).Z**(-1.19))
c          endif
c
          expi = expot( media.elem(i).Z )
c
          sumli=sumli + 
     *       media.elem(i).Z* media.No(i)/media.Z * log(expi)
       enddo
       media.I = exp(sumli)*1.d-9
       end

==> Epics.uv8.53.tar.gz: prog/Elemag/epExpot.f <==
c       ***************************************************************
c       *
c       *  epExpot:  compute excitation potential (in eV)
c       *            consisting of n different atoms.
c          
c         ---------------------------------
c          must be called after epGetEffZA
c         ---------------------------------
c       *
c
c /usage/ call epExpot(media)
c      
c           see p.r. b vol3 (1971)3681 sternheimer.  c

       subroutine epExpot(media)
       implicit none
#include "Zmedia.h"

       record /epmedia/media  !  input.  data  given by basic table must
                            !          be ready
                            !  output. media.I. ionization potential in GeV

       integer n

       integer i, j
       real*8 sumli, expi

       real expot(92)
c
c   From  http://physics.nist.gov/PhysRefData/XrayMassCoef/tab1.html
c    expot(Z) is excitation poential for Z in eV. Sep. 7, 2002
c
       data expot/
     1 19.2,  41.8,  40.0,  63.7,  76.0,   78.0,  82.0,  95.0, 115.0,
     2 137.0, 149.0, 156.0, 166.0, 173.0, 173.0, 180.0, 174.0, 188.0,
     3 190.0, 191.0, 216.0, 233.0, 245.0, 257.0, 272.0, 286.0, 297.0,
     4 311.0, 322.0, 330.0, 334.0, 350.0, 347.0, 348.0, 343.0, 352.0,
     5 363.0, 366.0, 379.0, 393.0, 417.0, 424.0, 428.0, 441.0, 449.0,
     6 470.0, 470.0, 469.0, 488.0, 488.0, 487.0, 485.0, 491.0, 482.0, 
     7 488.0, 491.0, 501.0, 523.0, 535.0, 546.0, 560.0, 574.0, 580.0,
     8 591.0, 614.0, 628.0, 650.0, 658.0, 674.0, 684.0, 694.0, 705.0,
     9 718.0, 727.0, 736.0, 746.0, 757.0, 790.0, 790.0, 800.0, 810.0,
     a 823.0, 823.0, 830.0, 825.0, 794.0, 827.0, 826.0, 841.0, 847.0,
     b 878.0, 890.0/


       sumli=0.



       n = media.noOfElem

       do  i = 1, n
c          if(media.elem(i).Z .eq. 1) then
c             expi=18.7
c          elseif(media.elem(i).Z .lt. 13.0) then
c             expi=13.*media.elem(i).Z
c          else
c             expi=media.elem(i).Z *( 9.76 + 58.8*
c     *            media.elem(i).Z**(-1.19))
c          endif
c
          j  =  media.elem(i).Z 
          expi = expot( j )   ! OSX absoft must use j for inteface
c
          sumli=sumli + 
     *       media.elem(i).Z* media.No(i)/media.Z * log(expi)
       enddo
       media.I = exp(sumli)*1.d-9
       end
